from django.db import models
from django.contrib.auth import get_user_model

User = get_user_model()
class Notification(models.Model):
    ACTION_TYPES = [
        ('liked', 'Liked'),
        ('commented', 'Commented'),
        ('followed', 'Followed'),
        ('viewed_profile', 'Viewed Profile'),
        ('follow_request', 'Follow Request'),
        ('follow_accepted', 'Follow Accepted'),
        ('added_to_casting_crew', 'Added to Casting Crew'),
        ('credit_request', 'Credit Request'),
        ('added_to_credit', 'Added to Credit'), 
        ('reported', 'Reported'),
        ('applicant_status', 'Applicant Status'),
        ('applied_users_request', 'Applied Users Request'),
        ('other', 'Other'),  
    ]
    
    user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='notifications')
    sender = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True, related_name="sent_notifications")  # Requester
    action_type = models.CharField(max_length=50, choices=ACTION_TYPES)
    message = models.CharField(max_length=255)
    is_read = models.BooleanField(default=False)
    created_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return f"Notification for {self.user.username} - {self.action_type}"
